@@ -1,13 +1,9 @@
-// NOTE: Boilerplate only.  Ignore this file.
-
 // Package v1 contains API Schema definitions for the tuned v1 API group
-// +k8s:deepcopy-gen=package,register
-// +groupName=tuned.openshift.io
 package v1
 
 import (
 	"k8s.io/apimachinery/pkg/runtime/schema"
-	"sigs.k8s.io/controller-runtime/pkg/runtime/scheme"
+	"sigs.k8s.io/controller-runtime/pkg/scheme"
 )
 
 var (
@@ -16,4 +12,7 @@ var (
 
 	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
 	SchemeBuilder = &scheme.Builder{GroupVersion: SchemeGroupVersion}
+
+	// AddToScheme adds the types in this group-version to the given scheme.
+	AddToScheme = SchemeBuilder.AddToScheme
 )
